# biotree_tools
Collection of bioinformatics tools related to alignments and phylogenetic trees

## Installation

conda install -c mmariotti -c bioconda -c etetoolkit  biotree_tools

## Tools
- **alignment_tools**  utility to manipulate (reformat, subset, trim...) multiple sequence alignments
- **tree_tools**       utility to manipulate (rename, prune, set output...) trees in newick format
- **phylo_context**    given protein sequences, build and draw a tree to identify phylogenetic (sub)families
- **show_tree**        flexible tool to visualize an input protein tree in newick format

Run any tool with option -h to display its usage.